@@ -2,15 +2,17 @@ from bisect import bisect_right
 from typing import Union
 
 from torch.optim import Optimizer
-from torch.optim.lr_scheduler import ReduceLROnPlateau as _ReduceLROnPlateau
-from torch.optim.lr_scheduler import _LRScheduler
+from torch.optim.lr_scheduler import (
+    ReduceLROnPlateau as _ReduceLROnPlateau,
+    _LRScheduler,
+)
 
 
 class LRScheduler:
     """Base class for schedulers"""
 
     def step(self, metric=None, step=None):
-        raise NotImplemented
+        raise NotImplementedError
 
 
 class ReduceLROnPlateau(_ReduceLROnPlateau, LRScheduler):
@@ -61,8 +63,8 @@ class WarmUpWrapper(Optimizer):
     def load_state_dict(self, state_dict: dict) -> None:
         self.optimizer.load_state_dict(state_dict)
 
-    def zero_grad(self) -> None:
-        self.optimizer.zero_grad()
+    def zero_grad(self, set_to_none=False) -> None:
+        self.optimizer.zero_grad(set_to_none)
 
     def add_param_group(self, param_group: dict) -> None:
         self.optimizer.add_param_group(param_group)
@@ -83,7 +85,7 @@ class IterativeScheduler(_LRScheduler, LRScheduler):
         return lrs
 
     def compute_lr(self, step):
-        raise NotImplemented
+        raise NotImplementedError
 
 
 class LinearLR(IterativeScheduler):
@@ -122,7 +124,7 @@ class StepLR(IterativeScheduler):
         self.step_size = step_size
         self.constant_step = isinstance(step_size, int)
 
-        if not self.constant_step:
+        if not isinstance(step_size, int):
             assert sorted(step_size) == step_size
             assert len(step_size) == len(set(step_size))
 
